mtd/fs/jffs2 background.c,1.42,1.43

David Woodhouse dwmw2 at infradead.org
Wed Oct 8 06:45:18 EDT 2003


Update of /home/cvs/mtd/fs/jffs2
In directory phoenix.infradead.org:/tmp/cvs-serv17048

Modified Files:
	background.c 
Log Message:
Switch to using SIGWINCH for waking GC thread. NPTL signal code will convert SIGHUP to SIGKILL 
since we have no handler (since we have no userspace).


Index: background.c
===================================================================
RCS file: /home/cvs/mtd/fs/jffs2/background.c,v
retrieving revision 1.42
retrieving revision 1.43
diff -u -r1.42 -r1.43
--- background.c	4 Oct 2003 08:33:05 -0000	1.42
+++ background.c	8 Oct 2003 10:45:15 -0000	1.43
@@ -29,7 +29,7 @@
 {
 	spin_lock(&c->erase_completion_lock);
         if (c->gc_task && thread_should_wake(c))
-                send_sig(SIGHUP, c->gc_task, 1);
+                send_sig(SIGWINCH, c->gc_task, 1);
 	spin_unlock(&c->erase_completion_lock);
 }
 
@@ -83,7 +83,7 @@
 
 	for (;;) {
 		spin_lock_irq(&current_sig_lock);
-		siginitsetinv (&current->blocked, sigmask(SIGHUP) | sigmask(SIGKILL) | sigmask(SIGSTOP) | sigmask(SIGCONT));
+		siginitsetinv (&current->blocked, sigmask(SIGWINCH) | sigmask(SIGKILL) | sigmask(SIGSTOP) | sigmask(SIGCONT));
 		recalc_sigpending();
 		spin_unlock_irq(&current_sig_lock);
 
@@ -123,14 +123,14 @@
 				spin_unlock(&c->erase_completion_lock);
 				complete_and_exit(&c->gc_thread_exit, 0);
 
-			case SIGHUP:
-				D1(printk(KERN_DEBUG "jffs2_garbage_collect_thread(): SIGHUP received.\n"));
+			case SIGWINCH:
+				D1(printk(KERN_DEBUG "jffs2_garbage_collect_thread(): SIGWINCH received.\n"));
 				break;
 			default:
 				D1(printk(KERN_DEBUG "jffs2_garbage_collect_thread(): signal %ld received\n", signr));
 			}
 		}
 		/* We don't want SIGHUP to interrupt us. STOP and KILL are OK though. */
 		spin_lock_irq(&current_sig_lock);
 		siginitsetinv (&current->blocked, sigmask(SIGKILL) | sigmask(SIGSTOP) | sigmask(SIGCONT));
 		recalc_sigpending();
@@ -123,14 +123,14 @@
 			}
 		}
-		/* We don't want SIGHUP to interrupt us. STOP and KILL are OK though. */
+		/* We don't want SIGWINCH to interrupt us. STOP and KILL are OK though. */
 		spin_lock_irq(&current_sig_lock);
 		siginitsetinv (&current->blocked, sigmask(SIGKILL) | sigmask(SIGSTOP) | sigmask(SIGCONT));




More information about the linux-mtd-cvs mailing list